@@ -1,4 +1,5 @@
 import django.conf
+from django.utils.functional import cached_property
 
 
 class Settings:
@@ -7,10 +8,13 @@ class Settings:
     instance will contain all of our settings as attributes, with default values
     if they are not specified by the configuration.
     """
-    defaults = {
-        'OTP_LOGIN_URL': django.conf.settings.LOGIN_URL,
-        'OTP_ADMIN_HIDE_SENSITIVE_DATA': False,
-    }
+
+    @cached_property
+    def defaults(self):
+        return {
+            'OTP_LOGIN_URL': django.conf.settings.LOGIN_URL,
+            'OTP_ADMIN_HIDE_SENSITIVE_DATA': False,
+        }
 
     def __getattr__(self, name):
         if name in self.defaults:
