@@ -44,10 +44,24 @@ class HOTPDevice(ThrottlingMixin, Device):
         *BigIntegerField*: The next counter value to expect. (Initial: 0)
 
     """
-    key = models.CharField(max_length=80, validators=[key_validator], default=default_key, help_text="A hex-encoded secret key of up to 40 bytes.")
-    digits = models.PositiveSmallIntegerField(choices=[(6, 6), (8, 8)], default=6, help_text="The number of digits to expect in a token.")
-    tolerance = models.PositiveSmallIntegerField(default=5, help_text="The number of missed tokens to tolerate.")
-    counter = models.BigIntegerField(default=0, help_text="The next counter value to expect.")
+
+    key = models.CharField(
+        max_length=80,
+        validators=[key_validator],
+        default=default_key,
+        help_text="A hex-encoded secret key of up to 40 bytes.",
+    )
+    digits = models.PositiveSmallIntegerField(
+        choices=[(6, 6), (8, 8)],
+        default=6,
+        help_text="The number of digits to expect in a token.",
+    )
+    tolerance = models.PositiveSmallIntegerField(
+        default=5, help_text="The number of missed tokens to tolerate."
+    )
+    counter = models.BigIntegerField(
+        default=0, help_text="The next counter value to expect."
+    )
 
     class Meta(Device.Meta):
         verbose_name = "HOTP device"
@@ -113,7 +127,9 @@ class HOTPDevice(ThrottlingMixin, Device):
         if isinstance(issuer, str) and (issuer != ''):
             issuer = issuer.replace(':', '')
             label = '{}:{}'.format(issuer, label)
-            urlencoded_params += '&issuer={}'.format(quote(issuer))  # encode issuer as per RFC 3986, not quote_plus
+            urlencoded_params += '&issuer={}'.format(
+                quote(issuer)
+            )  # encode issuer as per RFC 3986, not quote_plus
 
         url = 'otpauth://hotp/{}?{}'.format(quote(label), urlencoded_params)
 
