@@ -16,10 +16,14 @@ class StaticDeviceAdmin(admin.ModelAdmin):
     :class:`~django.contrib.admin.ModelAdmin` for
     :class:`~django_otp.plugins.otp_static.models.StaticDevice`.
     """
+
     fieldsets = [
-        ('Identity', {
-            'fields': ['user', 'name', 'confirmed'],
-        }),
+        (
+            'Identity',
+            {
+                'fields': ['user', 'name', 'confirmed'],
+            },
+        ),
     ]
     raw_id_fields = ['user']
 
